How to accomplish a task
========================

Here you would explain how to use tickit to accomplish
a particular task. It doesn't have to be an exhaustive guide like the tutorials,
just enough information to show someone who knows what they want to do, how to
accomplish that task.
